# coding: utf-8

"""
    Gitea API

    This documentation describes the Gitea API.

    The version of the OpenAPI document: 1.25.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_gitea_opensuse_org.models.contents_ext_response import ContentsExtResponse

class TestContentsExtResponse(unittest.TestCase):
    """ContentsExtResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ContentsExtResponse:
        """Test ContentsExtResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ContentsExtResponse`
        """
        model = ContentsExtResponse()
        if include_optional:
            return ContentsExtResponse(
                dir_contents = [
                    py_gitea_opensuse_org.models.contents_response.ContentsResponse(
                        _links = py_gitea_opensuse_org.models.file_links_response.FileLinksResponse(
                            git = '', 
                            html = '', 
                            self = '', ), 
                        content = '', 
                        download_url = '', 
                        encoding = '', 
                        git_url = '', 
                        html_url = '', 
                        last_author_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        last_commit_message = '', 
                        last_commit_sha = '', 
                        last_committer_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        lfs_oid = '', 
                        lfs_size = 56, 
                        name = '', 
                        path = '', 
                        sha = '', 
                        size = 56, 
                        submodule_git_url = '', 
                        target = '', 
                        type = '', 
                        url = '', )
                    ],
                file_contents = py_gitea_opensuse_org.models.contents_response.ContentsResponse(
                    _links = py_gitea_opensuse_org.models.file_links_response.FileLinksResponse(
                        git = '', 
                        html = '', 
                        self = '', ), 
                    content = '', 
                    download_url = '', 
                    encoding = '', 
                    git_url = '', 
                    html_url = '', 
                    last_author_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    last_commit_message = '', 
                    last_commit_sha = '', 
                    last_committer_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    lfs_oid = '', 
                    lfs_size = 56, 
                    name = '', 
                    path = '', 
                    sha = '', 
                    size = 56, 
                    submodule_git_url = '', 
                    target = '', 
                    type = '', 
                    url = '', )
            )
        else:
            return ContentsExtResponse(
        )
        """

    def testContentsExtResponse(self):
        """Test ContentsExtResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
