# coding: utf-8

"""
    Gitea API

    This documentation describes the Gitea API.

    The version of the OpenAPI document: 1.25.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class EditPullRequestOption(BaseModel):
    """
    EditPullRequestOption options when modify pull request
    """ # noqa: E501
    allow_maintainer_edit: Optional[StrictBool] = Field(default=None, description="Whether to allow maintainer edits")
    assignee: Optional[StrictStr] = Field(default=None, description="The new primary assignee username")
    assignees: Optional[List[StrictStr]] = Field(default=None, description="The new list of assignee usernames")
    base: Optional[StrictStr] = Field(default=None, description="The new base branch for the pull request")
    body: Optional[StrictStr] = Field(default=None, description="The new description body for the pull request")
    due_date: Optional[datetime] = None
    labels: Optional[List[StrictInt]] = Field(default=None, description="The new list of label IDs for the pull request")
    milestone: Optional[StrictInt] = Field(default=None, description="The new milestone ID for the pull request")
    state: Optional[StrictStr] = Field(default=None, description="The new state for the pull request")
    title: Optional[StrictStr] = Field(default=None, description="The new title for the pull request")
    unset_due_date: Optional[StrictBool] = Field(default=None, description="Whether to remove the current deadline")
    __properties: ClassVar[List[str]] = ["allow_maintainer_edit", "assignee", "assignees", "base", "body", "due_date", "labels", "milestone", "state", "title", "unset_due_date"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of EditPullRequestOption from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of EditPullRequestOption from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "allow_maintainer_edit": obj.get("allow_maintainer_edit"),
            "assignee": obj.get("assignee"),
            "assignees": obj.get("assignees"),
            "base": obj.get("base"),
            "body": obj.get("body"),
            "due_date": obj.get("due_date"),
            "labels": obj.get("labels"),
            "milestone": obj.get("milestone"),
            "state": obj.get("state"),
            "title": obj.get("title"),
            "unset_due_date": obj.get("unset_due_date")
        })
        return _obj


