# coding: utf-8

"""
    Gitea API

    This documentation describes the Gitea API.

    The version of the OpenAPI document: 1.25.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_gitea_opensuse_org.models.action_workflow_jobs_response import ActionWorkflowJobsResponse

class TestActionWorkflowJobsResponse(unittest.TestCase):
    """ActionWorkflowJobsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ActionWorkflowJobsResponse:
        """Test ActionWorkflowJobsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ActionWorkflowJobsResponse`
        """
        model = ActionWorkflowJobsResponse()
        if include_optional:
            return ActionWorkflowJobsResponse(
                jobs = [
                    py_gitea_opensuse_org.models.action_workflow_job.ActionWorkflowJob(
                        completed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        conclusion = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        head_branch = '', 
                        head_sha = '', 
                        html_url = '', 
                        id = 56, 
                        labels = [
                            ''
                            ], 
                        name = '', 
                        run_attempt = 56, 
                        run_id = 56, 
                        run_url = '', 
                        runner_id = 56, 
                        runner_name = '', 
                        started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        status = '', 
                        steps = [
                            py_gitea_opensuse_org.models.action_workflow_step.ActionWorkflowStep(
                                completed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                conclusion = '', 
                                name = '', 
                                number = 56, 
                                started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                status = '', )
                            ], 
                        url = '', )
                    ],
                total_count = 56
            )
        else:
            return ActionWorkflowJobsResponse(
        )
        """

    def testActionWorkflowJobsResponse(self):
        """Test ActionWorkflowJobsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
