# coding: utf-8

"""
    Gitea API

    This documentation describes the Gitea API.

    The version of the OpenAPI document: 1.25.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from py_gitea_opensuse_org.models.repository import Repository
from py_gitea_opensuse_org.models.user import User
from typing import Optional, Set
from typing_extensions import Self

class ActionWorkflowRun(BaseModel):
    """
    ActionWorkflowRun represents a WorkflowRun
    """ # noqa: E501
    actor: Optional[User] = None
    completed_at: Optional[datetime] = None
    conclusion: Optional[StrictStr] = None
    display_title: Optional[StrictStr] = None
    event: Optional[StrictStr] = None
    head_branch: Optional[StrictStr] = None
    head_repository: Optional[Repository] = None
    head_sha: Optional[StrictStr] = None
    html_url: Optional[StrictStr] = None
    id: Optional[StrictInt] = None
    path: Optional[StrictStr] = None
    repository: Optional[Repository] = None
    repository_id: Optional[StrictInt] = None
    run_attempt: Optional[StrictInt] = None
    run_number: Optional[StrictInt] = None
    started_at: Optional[datetime] = None
    status: Optional[StrictStr] = None
    trigger_actor: Optional[User] = None
    url: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["actor", "completed_at", "conclusion", "display_title", "event", "head_branch", "head_repository", "head_sha", "html_url", "id", "path", "repository", "repository_id", "run_attempt", "run_number", "started_at", "status", "trigger_actor", "url"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ActionWorkflowRun from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of actor
        if self.actor:
            _dict['actor'] = self.actor.to_dict()
        # override the default output from pydantic by calling `to_dict()` of head_repository
        if self.head_repository:
            _dict['head_repository'] = self.head_repository.to_dict()
        # override the default output from pydantic by calling `to_dict()` of repository
        if self.repository:
            _dict['repository'] = self.repository.to_dict()
        # override the default output from pydantic by calling `to_dict()` of trigger_actor
        if self.trigger_actor:
            _dict['trigger_actor'] = self.trigger_actor.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ActionWorkflowRun from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "actor": User.from_dict(obj["actor"]) if obj.get("actor") is not None else None,
            "completed_at": obj.get("completed_at"),
            "conclusion": obj.get("conclusion"),
            "display_title": obj.get("display_title"),
            "event": obj.get("event"),
            "head_branch": obj.get("head_branch"),
            "head_repository": Repository.from_dict(obj["head_repository"]) if obj.get("head_repository") is not None else None,
            "head_sha": obj.get("head_sha"),
            "html_url": obj.get("html_url"),
            "id": obj.get("id"),
            "path": obj.get("path"),
            "repository": Repository.from_dict(obj["repository"]) if obj.get("repository") is not None else None,
            "repository_id": obj.get("repository_id"),
            "run_attempt": obj.get("run_attempt"),
            "run_number": obj.get("run_number"),
            "started_at": obj.get("started_at"),
            "status": obj.get("status"),
            "trigger_actor": User.from_dict(obj["trigger_actor"]) if obj.get("trigger_actor") is not None else None,
            "url": obj.get("url")
        })
        return _obj


