# coding: utf-8

"""
    Gitea API

    This documentation describes the Gitea API.

    The version of the OpenAPI document: 1.25.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class CreatePullRequestOption(BaseModel):
    """
    CreatePullRequestOption options when creating a pull request
    """ # noqa: E501
    assignee: Optional[StrictStr] = Field(default=None, description="The primary assignee username")
    assignees: Optional[List[StrictStr]] = Field(default=None, description="The list of assignee usernames")
    base: Optional[StrictStr] = Field(default=None, description="The base branch for the pull request")
    body: Optional[StrictStr] = Field(default=None, description="The description body of the pull request")
    due_date: Optional[datetime] = None
    head: Optional[StrictStr] = Field(default=None, description="The head branch for the pull request, it could be a branch name on the base repository or a form like `<username>:<branch>` which refers to the user's fork repository's branch.")
    labels: Optional[List[StrictInt]] = Field(default=None, description="The list of label IDs to assign to the pull request")
    milestone: Optional[StrictInt] = Field(default=None, description="The milestone ID to assign to the pull request")
    reviewers: Optional[List[StrictStr]] = Field(default=None, description="The list of reviewer usernames")
    team_reviewers: Optional[List[StrictStr]] = Field(default=None, description="The list of team reviewer names")
    title: Optional[StrictStr] = Field(default=None, description="The title of the pull request")
    __properties: ClassVar[List[str]] = ["assignee", "assignees", "base", "body", "due_date", "head", "labels", "milestone", "reviewers", "team_reviewers", "title"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CreatePullRequestOption from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CreatePullRequestOption from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "assignee": obj.get("assignee"),
            "assignees": obj.get("assignees"),
            "base": obj.get("base"),
            "body": obj.get("body"),
            "due_date": obj.get("due_date"),
            "head": obj.get("head"),
            "labels": obj.get("labels"),
            "milestone": obj.get("milestone"),
            "reviewers": obj.get("reviewers"),
            "team_reviewers": obj.get("team_reviewers"),
            "title": obj.get("title")
        })
        return _obj


